# Requirements

## Highly Important

### Design Principles

* Reproducibility
  * [snakemake rolling paper](https://f1000research.com/articles/10-33/v1)
* Scalability
* Federated Components
* Open Source aka Minimal Building From Scratch
* Operationally Robust
* Business Continuity
* Imperfection
* Let robots do what they do best (repetitive tasks) and humans do what they do best (creative tasks, debugging, exceptions)
* Connect process monitoring data and insights to process improvement
* Expect, do not fear failure and errors. Plan for fast recovery, citation: 
* Culture, not just software
* Prepare for scale

### Data Model

* [ ga4gh] Data model is designed to be compliant with the [GA4GH](https://www.ga4gh.org/) [Data Model](
* [ ] 